pub fn subscribe<T, F>(progress_report: F)where T: 'static + Send + Sync, F: 'static + Sync + Send + Fn(StatusUpdate<T>),
Subscribes to progress reports of type T with callback of type F called every time progress is made with type T.